@@ -13,6 +13,7 @@ from slack import WebClient
 from slack.errors import SlackApiError
 from pathlib import Path
 from joblib import dump
+
 from Accuinsight.modeler.core import func, path, get
 from Accuinsight.modeler.core.func import get_time
 from Accuinsight.modeler.core.get_for_visual import roc_pr_curve, get_visual_info_regressor, get_true_y, get_visual_info_regressor
@@ -22,12 +23,14 @@ from Accuinsight.modeler.core.LcConst.LcConst import ALL_MODEL_PARAMS, SELECTED_
     LOGGING_TIME, LOGGING_RUN_ID, FITTED_MODEL, RUN_PREFIX_PATH, RUN_MODEL_JSON_PATH, RUN_MODEL_VISUAL_JSON_PATH, \
     RUN_MODEL_HOME_PATH, ENV_JUPYTER_HOME_DIR
 from Accuinsight.modeler.core.Run.RunInfo.RunInfo import set_current_runs, clear_runs, print_run_info, \
-    set_git_meta, set_python_dependencies, set_run_name, set_model_json_path, set_visual_json_path, set_model_file_path, set_prefix_path, set_best_model_joblib_path, _set_result_path, set_shap_json_path 
+    set_git_meta, set_python_dependencies, set_run_name, set_model_json_path, set_visual_json_path, set_model_file_path, set_prefix_path, set_best_model_joblib_path, _set_result_path, set_shap_json_path
 from Accuinsight.modeler.utils.dependency.dependencies import gather_sources_and_dependencies
 from Accuinsight.modeler.core.LcConst import LcConst
 from Accuinsight.modeler.utils.os_getenv import is_in_ipython, get_current_notebook
 from Accuinsight.modeler.clients.modeler_api import LifecycleRestApi
-from Accuinsight.modeler.core.feature_contribution import shap_value 
+
+from Accuinsight.modeler.core.feature_contribution import shap_value
+from Accuinsight.modeler.core import metricsLightgbm
 
 
 logging.basicConfig(level=logging.INFO,
@@ -38,94 +41,62 @@ warnings.filterwarnings("ignore")
 
 class accuinsight(object):
     def __init__(self):
-        self.StorageInfo = None
+        self.BucketInfo = None
         self.endpoint = None
+        
 
-    def get_file(self, storage_json_file_name):
+    def get_file(self, aws_json_file_name):
         global save_path, target_name, bucket_info
         
         # meta file 저장하는 폴더 만들면, 이 경로는 수정돼야 함.
-        storage_info_json_path = os.path.join(ENV_JUPYTER_HOME_DIR, storage_json_file_name)
-    
-        with open(storage_info_json_path) as jsonFile:
-            self.StorageInfo = json.load(jsonFile)
+        aws_info_json_path = os.path.join(ENV_JUPYTER_HOME_DIR, aws_json_file_name)
     
+        with open(aws_info_json_path) as jsonFile:
+            self.BucketInfo = json.load(jsonFile)
+            
+        BUCKET_TYPE = self.BucketInfo['bucketType']
+        BUCKET_NAME = self.BucketInfo['bucketName']
+        FILE_PATH = self.BucketInfo['filePath']
+        FILE_NAME = self.BucketInfo['fileName']
+        #FILE_TYPE = self.BucketInfo['fileType']
+        #FILE_DELIM = self.BucketInfo['fileDelim']
+        ACCESS_KEY = self.BucketInfo['myAccessKey']
+        SECRET_KEY = self.BucketInfo['mySecretKey']
+        REGION = self.BucketInfo['region']
+        URL = self.BucketInfo['endpoint']
+        
         ## define the target name
-        target_name = self.StorageInfo['target']
-        
-        
-        if 'host' in self.StorageInfo.keys():    # HDFS
-            
-            ## path for saving data
-            save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_hdfs')
-            if os.path.exists(save_dir) == False:
-                os.mkdir(save_dir)
-            else:
-                pass
-            
-            split_list = list(filter(None, self.StorageInfo['filePath'].split('/')))
-            
-            HOST = self.StorageInfo['host']
-            PORT = int(self.StorageInfo['port'])
-            FILE_PATH = self.StorageInfo['filePath']
-            FILE_DIR = '/'
-            for i in split_list[:len(split_list)-1]:
-                FILE_DIR = os.path.join(FILE_DIR, i)
-            FILE_NAME = split_list[-1]
-            
-            self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
-            self.save_path = os.path.join(save_dir, self.save_file_name)
-            self.endpoint = os.path.join('hdfs://', HOST, self.StorageInfo['port']) + FILE_PATH
-            
-            hdfs = HDFileSystem(host = HOST, port = PORT)
-            hdfs.ls(FILE_DIR)
+        target_name = self.BucketInfo['target']
 
-            sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
-            time.sleep(1)
-            hdfs.get(FILE_PATH, self.save_path)
-            logging.info(self.save_path)
-        
-        
-        else:     # AWS-S3
-            BUCKET_TYPE = self.StorageInfo['bucketType']
-            BUCKET_NAME = self.StorageInfo['bucketName']
-            FILE_PATH = self.StorageInfo['filePath']
-            FILE_NAME = self.StorageInfo['fileName']
-            #FILE_TYPE = self.StorageInfo['fileType']
-            #FILE_DELIM = self.StorageInfo['fileDelim']
-            ACCESS_KEY = self.StorageInfo['myAccessKey']
-            SECRET_KEY = self.StorageInfo['mySecretKey']
-            REGION = self.StorageInfo['region']
-            URL = self.StorageInfo['endpoint']
+        ## path for saving data
+        save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_AWS')
 
-            ## path for saving data
-            save_dir = os.path.join(ENV_JUPYTER_HOME_DIR, 'data_from_aws')
-            if os.path.exists(save_dir) == False:
-                os.mkdir(save_dir)
-            else:
-                pass
+        if os.path.exists(save_dir) == False:
+            os.mkdir(save_dir)
+        else:
+            pass
   
-            self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
-            save_path = os.path.join(save_dir, self.save_file_name)
+        self.save_file_name = FILE_NAME.split('.')[0] + '_' + str(datetime.datetime.now().date()).replace('-', '') + '.' + FILE_NAME.split('.')[1]
+        save_path = os.path.join(save_dir, self.save_file_name)
 
-            # endpoint
-            pre_url = 'https://' + BUCKET_NAME + '.' + URL
-            self.endpoint = os.path.join(pre_url, FILE_PATH)
+        # endpoint
+        pre_url = 'https://' + BUCKET_NAME + '.' + URL
+        self.endpoint = os.path.join(pre_url, FILE_PATH)
 
-            client = boto3.client(BUCKET_TYPE,
-                                  aws_access_key_id=ACCESS_KEY,
-                                  aws_secret_access_key=SECRET_KEY,
-                                  region_name=REGION)
+        client = boto3.client(BUCKET_TYPE,
+                              aws_access_key_id=ACCESS_KEY,
+                              aws_secret_access_key=SECRET_KEY,
+                              region_name=REGION)
 
-            transfer = boto3.s3.transfer.S3Transfer(client)
+        transfer = boto3.s3.transfer.S3Transfer(client)
 
-            progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
-    
-            sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
-            transfer.download_file(BUCKET_NAME, FILE_PATH, save_path, callback=progress)
-            logging.info(save_path)
+        progress = ProgressPercentage(client, BUCKET_NAME, FILE_PATH)
+
+        sys.stdout.write('%s %s %s' % ('Downloading file...', FILE_NAME, '\n'))
+        transfer.download_file(BUCKET_NAME, FILE_PATH, save_path, callback=progress)
+        logging.info(save_path)
         
-        bucket_info = self.StorageInfo
+        bucket_info = self.BucketInfo
     
     def set_slack(self, token = None, channel_id = None):
         self.token = token
@@ -189,7 +160,7 @@ class accuinsight(object):
             set_current_runs(get.model_type(self.model_name))
             _set_result_path(self.dict_path)
 
-            # visualization function
+            # data for visualization function
             if len(args) == 2:
                 self.xval = args[0]
                 self.yval = args[1]
@@ -203,6 +174,13 @@ class accuinsight(object):
             else:
                 raise ValueError('Check the arguments of function - add_experiment(model_name, X_val, y_val) or add_experiment(model_name, X_train, y_train, X_val, y_val)')
 
+            
+            # sklearn/xgboost/lightgbm
+            get_from_model = get.from_model(self.model_name)
+            self.all_model_params = get_from_model.all_params()
+            self.model_param_keys = get_from_model.param_keys()
+            
+            
             # classifier
             if any(i in self.fitted_model for i in CLASSIFICATION):
                 self.vis_info = roc_pr_curve(self.model_name, self.xval, self.yval)
@@ -210,12 +188,22 @@ class accuinsight(object):
             # regressor
             elif any(i in self.fitted_model for i in REGRESSION):
                 self.ypred = get_visual_info_regressor(self.model_name, self.xval)
+            
+            # if user uses lightgbm package, verify the model for classification or regression.
+            if self.fitted_model == 'lightgbm':
                 
-            # sklearn/xgboost/lightgbm
-            get_from_model = get.from_model(self.model_name)
-            self.all_model_params = get_from_model.all_params()
-            self.model_param_keys = get_from_model.param_keys()
-
+                # classifier
+                if self.all_model_params['metric'] in metricsLightgbm.CLASSIFICATION:
+                    self.vis_info = roc_pr_curve(self.model_name, self.xval, self.yval)
+                
+                # regressor
+                elif self.all_model_params['metric'] in metricsLightgbm.REGRESSION:
+                    self.ypred = get_visual_info_regressor(self.model_name, self.xval)
+                
+                # None
+                elif self.all_model_params['metric'] in metricsLightgbm.no_metrics:
+                    raise ValueError('Please set any metric parameter in the lightGBM.')
+            
             set_model_file_path(self.var_model_file_path)
 
             if hasattr(self, 'mainfile'):
@@ -250,6 +238,10 @@ class accuinsight(object):
                     self.feature_name = None
                 self.run_id = self.fitted_model + '-' + self.run_id
                 
+                # when user uses lightGBM fitted by lightGBM datasets, convert data type to lightGBM dataset.
+                if self.fitted_model == 'lightgbm':
+                    self.xtrain = lgb.Dataset(self.xtrain, label=self.ytrain, silent=True)
+                        
                 self.shap_value = shap_value(self.model_name, self.xtrain, self.feature_name)
                 
                 # path for shap.json
@@ -259,11 +251,11 @@ class accuinsight(object):
                 with open(shap_json_full_path, 'w', encoding = 'utf-8') as save_file:
                     json.dump(self.shap_value, save_file, indent='\t')
                 
-            else:   
+            else:
                 pass
                 
             # visualization
-            if any(i in self.fitted_model for i in CLASSIFICATION):
+            if any(i in self.fitted_model for i in CLASSIFICATION) or self.all_model_params['metric'] in metricsLightgbm.CLASSIFICATION:
 
                 # path for visual.json
                 visual_json_full_path = self.dict_path['visual_json_full']
@@ -272,7 +264,7 @@ class accuinsight(object):
                 with open(visual_json_full_path, 'w', encoding='utf-8') as save_file1:
                     json.dump(self.vis_info, save_file1, indent="\t")
 
-            elif any(i in self.fitted_model for i in REGRESSION):
+            elif any(i in self.fitted_model for i in REGRESSION) or self.all_model_params['metric'] in metricsLightgbm.REGRESSION:
                 temp_yval = get_true_y(self.yval)
                 if len(temp_yval) <= 5000:
                     self.summary_info['True_y'] = temp_yval
@@ -290,6 +282,7 @@ class accuinsight(object):
 
                 with open(model_json_full_path, 'w', encoding='utf-8') as save_file2:
                     json.dump(self.summary_info, save_file2, indent="\t")
+                    
             else:
                 pass
 
@@ -328,3 +321,4 @@ class accuinsight(object):
 
         def log_tag(self, description):
             self.summary_info['tag'] = description
+
