@@ -19,7 +19,10 @@ def model_type(model_name):
         return('pytorch')
     
     else:
-        tmp_name = str(model_name)[:str(model_name).find('(')]
+        if '(' in str(model_name):
+            tmp_name = str(model_name)[:str(model_name).find('(')]
+        elif '<' in str(model_name):
+            tmp_name = str(model_name).split('.')[0][1:]
         
         if any(i in tmp_name for i in ONEVS):
             idx1 = list(mit.locate(str(model_name), lambda x: x == "="))[0]
@@ -80,9 +83,13 @@ def trial_num_json(DB_path, file_type):
 # model parameter
 class from_model(object):
     def __init__(self, model_name):
-        self.parDict = model_name.get_params()
-        self.keyList = list(model_name.get_params().keys())
-        
+        try:
+            self.parDict = model_name.get_params()
+            self.keyList = list(model_name.get_params().keys())
+        except:                                                   # lightGBM
+            self.parDict = model_name.params
+            self.keyList = list(model_name.params.keys())
+            
     def all_params(self):
  
         # multiclass
@@ -98,7 +105,8 @@ class from_model(object):
             for i in range(len(parkey)):
                 all_dict[parkey[i]] = parvalue[i]
             
-            all_dict.pop('random_state')
+            if 'random_state' in all_dict.keys():
+                all_dict.pop('random_state')
             
             return(all_dict)
         
@@ -136,12 +144,8 @@ def is_classification(model_name):
         else:
             raise ValueError('현재 설정한 loss는 지원되지 않습니다. 관리자에게 문의하십시오.')
             
-def feature_name(savedPath, StorageInfo, targetName):
-    if 'host' in StorageInfo:  # HDFS
-        fileType = StorageInfo['filePath'].split('.')[1]
-    
-    else: # AWS S3
-        fileType = StorageInfo['fileName'].split('.')[1]
+def feature_name(savedPath, bucketInfo, targetName):
+    fileType = bucketInfo['fileName'].split('.')[1]
         
     if fileType == 'json':
         with open(savedPath) as jsonFile:
@@ -149,7 +153,7 @@ def feature_name(savedPath, StorageInfo, targetName):
         feature_name = list(json_data.keys())
     elif fileType == 'csv':
         feature_name = list(pd.read_csv(savedPath).columns)
-        if 'Unnamed: 0' in feature_name and feature_name[0]=='Unnamed: 0':
+        if 'Unnamed: 0' in feature_name:
             feature_name.remove('Unnamed: 0')
     else:
         raise TypeError('{type}은 지원하지 않는 데이터 형식입니다. 현재 지원하는 데이터 형식은 json과 csv입니다.'.format(type=fileType))
